@@ -5,20 +5,42 @@ import string
 from shlex import shlex
 from io import open
 from collections import OrderedDict
-from distutils.util import strtobool
 
 # Useful for very coarse version differentiation.
-PY3 = sys.version_info[0] == 3
+PYVERSION = sys.version_info
 
-if PY3:
+
+if PYVERSION >= (3, 0, 0):
     from configparser import ConfigParser
     text_type = str
 else:
     from ConfigParser import SafeConfigParser as ConfigParser
     text_type = unicode
 
+if PYVERSION >= (3, 2, 0):
+    read_config = lambda parser, file: parser.read_file(file)
+else:
+    read_config = lambda parser, file: parser.readfp(file)
+
+
 DEFAULT_ENCODING = 'UTF-8'
 
+
+# Python 3.10 don't have strtobool anymore. So we move it here.
+TRUE_VALUES = {"y", "yes", "t", "true", "on", "1"}
+FALSE_VALUES = {"n", "no", "f", "false", "off", "0"}
+
+def strtobool(value):
+    value = value.lower()
+
+    if value in TRUE_VALUES:
+        return True
+    elif value in FALSE_VALUES:
+        return False
+
+    raise ValueError("Invalid truth value: " + value)
+
+
 class UndefinedValueError(Exception):
     pass
 
@@ -103,7 +125,7 @@ class RepositoryIni(RepositoryEmpty):
     def __init__(self, source, encoding=DEFAULT_ENCODING):
         self.parser = ConfigParser()
         with open(source, encoding=encoding) as file_:
-            self.parser.readfp(file_)
+            read_config(self.parser, file_)
 
     def __contains__(self, key):
         return (key in os.environ or
@@ -129,7 +151,7 @@ class RepositoryEnv(RepositoryEmpty):
                 k = k.strip()
                 v = v.strip()
                 if len(v) >= 2 and ((v[0] == "'" and v[-1] == "'") or (v[0] == '"' and v[-1] == '"')):
-                    v = v.strip('\'"')
+                    v = v[1:-1]
                 self.data[k] = v
 
     def __contains__(self, key):
@@ -139,6 +161,28 @@ class RepositoryEnv(RepositoryEmpty):
         return self.data[key]
 
 
+class RepositorySecret(RepositoryEmpty):
+    """
+    Retrieves option keys from files,
+    where title of file is a key, content of file is a value
+    e.g. Docker swarm secrets
+    """
+
+    def __init__(self, source='/run/secrets/'):
+        self.data = {}
+
+        ls = os.listdir(source)
+        for file in ls:
+            with open(os.path.join(source, file), 'r') as f:
+                self.data[file] = f.read()
+
+    def __contains__(self, key):
+        return key in os.environ or key in self.data
+
+    def __getitem__(self, key):
+        return self.data[key]
+
+
 class AutoConfig(object):
     """
     Autodetects the config file and type.
@@ -254,7 +298,6 @@ class Choices(object):
         self._valid_values.extend(self.flat)
         self._valid_values.extend([value for value, _ in self.choices])
 
-
     def __call__(self, value):
         transform = self.cast(value)
         if transform not in self._valid_values:
